# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.0.1] - 2020-07-13
### Fixed
- Update docs to reflect package name change from `surveyor` to `datasurveyor


## [0.0.0] - 2020-07-13
- Initial release
